@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-#$Id: watch.pl 473 2009-10-07 20:35:21Z pro $ $URL: svn://svn.setun.net/dcppp/trunk/examples/watch.pl $
+#$Id: watch.pl 535 2010-01-11 02:42:50Z pro $ $URL: svn://svn.setun.net/dcppp/trunk/examples/watch.pl $
 
 =readme
 
@@ -10,13 +10,14 @@ chat watch
 use strict;
 eval { use Time::HiRes qw(time sleep); };
 use lib '../lib';
-use Net::DirectConnect::clihub;
-print("usage: flood.pl [dchub://]host[:port] [bot_nick]\n"), exit if !$ARGV[0];
+use Net::DirectConnect;    #::clihub;
+print("usage: $0 [adc|dchub://]host[:port] [bot_nick]\n"), exit if !$ARGV[0];
 #print "Arg=",$ARGV[0],"\n";
-$ARGV[0] =~ m|^(?:dchub\://)?(.+?)(?:\:(\d+))?$|;
-my $dc = Net::DirectConnect::clihub->new(
-  'host' => $1,
-  ( $2 ? ( 'port' => $2 ) : () ),
+#$ARGV[0] =~ m|^(?:\w+\://)?(.+?)(?:\:(\d+))?$|;
+my $dc = Net::DirectConnect->new(
+  #'host' => $1,
+  'host' => $ARGV[0],
+  #( $2 ? ( 'port' => $2 ) : () ),
   'Nick' => ( $ARGV[1] or int( rand(100000000) ) ),
   #'Nick'		=>	'xxxx',
   'sharesize' => int( rand 100000000000 ) + int( rand 10000000000 ) * int( rand 100 ),
